@@ -51,11 +51,9 @@ init_mb_mgr_avx512_internal(IMB_MGR *state, const int reset_mgrs)
         /* reset error status */
         imb_set_errno(state, 0);
 
-        state->features = cpu_feature_adjust(state->flags,
-                                             cpu_feature_detect());
+        state->features = cpu_feature_adjust(state->flags, cpu_feature_detect());
 
-        if ((state->features & IMB_CPUFLAGS_AVX512_T2) ==
-            IMB_CPUFLAGS_AVX512_T2)
+        if ((state->features & IMB_CPUFLAGS_AVX512_T2) == IMB_CPUFLAGS_AVX512_T2)
                 init_mb_mgr_avx512_t2_internal(state, reset_mgrs);
         else
                 init_mb_mgr_avx512_t1_internal(state, reset_mgrs);
@@ -70,32 +68,38 @@ init_mb_mgr_avx512(IMB_MGR *state)
                 imb_set_errno(state, IMB_ERR_SELFTEST);
 }
 
-IMB_JOB *submit_job_avx512(IMB_MGR *state)
+IMB_JOB *
+submit_job_avx512(IMB_MGR *state)
 {
         return IMB_SUBMIT_JOB(state);
 }
 
-IMB_JOB *flush_job_avx512(IMB_MGR *state)
+IMB_JOB *
+flush_job_avx512(IMB_MGR *state)
 {
         return IMB_FLUSH_JOB(state);
 }
 
-uint32_t queue_size_avx512(IMB_MGR *state)
+uint32_t
+queue_size_avx512(IMB_MGR *state)
 {
         return IMB_QUEUE_SIZE(state);
 }
 
-IMB_JOB *submit_job_nocheck_avx512(IMB_MGR *state)
+IMB_JOB *
+submit_job_nocheck_avx512(IMB_MGR *state)
 {
         return IMB_SUBMIT_JOB_NOCHECK(state);
 }
 
-IMB_JOB *get_next_job_avx512(IMB_MGR *state)
+IMB_JOB *
+get_next_job_avx512(IMB_MGR *state)
 {
         return IMB_GET_NEXT_JOB(state);
 }
 
-IMB_JOB *get_completed_job_avx512(IMB_MGR *state)
+IMB_JOB *
+get_completed_job_avx512(IMB_MGR *state)
 {
         return IMB_GET_COMPLETED_JOB(state);
 }
