@@ -35,13 +35,12 @@
 #include "include/clear_regs_mem.h"
 #include "include/error.h"
 
-#define SAVE_XMMS               save_xmms_avx
-#define RESTORE_XMMS            restore_xmms_avx
+#define SAVE_XMMS    save_xmms_avx
+#define RESTORE_XMMS restore_xmms_avx
 
 void
-kasumi_f8_1_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV,
-                       const void *pBufferIn, void *pBufferOut,
-                       const uint32_t cipherLengthInBytes)
+kasumi_f8_1_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV, const void *pBufferIn,
+                       void *pBufferOut, const uint32_t cipherLengthInBytes)
 {
 #ifndef LINUX
         DECLARE_ALIGNED(imb_uint128_t xmm_save[10], 16);
@@ -51,7 +50,7 @@ kasumi_f8_1_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV,
 #ifdef SAFE_PARAM
         /* Check for NULL pointers */
         imb_set_errno(NULL, 0);
-        if (pCtx ==  NULL) {
+        if (pCtx == NULL) {
                 imb_set_errno(NULL, IMB_ERR_NULL_EXP_KEY);
                 return;
         }
@@ -64,14 +63,12 @@ kasumi_f8_1_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV,
                 return;
         }
         /* Check input data is in range of supported length */
-        if (cipherLengthInBytes == 0 ||
-            cipherLengthInBytes > (KASUMI_MAX_LEN / CHAR_BIT)) {
+        if (cipherLengthInBytes == 0 || cipherLengthInBytes > (KASUMI_MAX_LEN / CHAR_BIT)) {
                 imb_set_errno(NULL, IMB_ERR_CIPH_LEN);
                 return;
         }
 #endif
-        kasumi_f8_1_buffer(pCtx, IV, pBufferIn, pBufferOut,
-                           cipherLengthInBytes);
+        kasumi_f8_1_buffer(pCtx, IV, pBufferIn, pBufferOut, cipherLengthInBytes);
 #ifdef SAFE_DATA
         /* Clear sensitive data in registers */
         CLEAR_SCRATCH_GPS();
@@ -83,10 +80,8 @@ kasumi_f8_1_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV,
 }
 
 void
-kasumi_f8_1_buffer_bit_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV,
-                           const void *pBufferIn,
-                           void *pBufferOut,
-                           const uint32_t cipherLengthInBits,
+kasumi_f8_1_buffer_bit_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV, const void *pBufferIn,
+                           void *pBufferOut, const uint32_t cipherLengthInBits,
                            const uint32_t offsetInBits)
 {
 #ifndef LINUX
@@ -97,7 +92,7 @@ kasumi_f8_1_buffer_bit_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV,
 #ifdef SAFE_PARAM
         /* Check for NULL pointers */
         imb_set_errno(NULL, 0);
-        if (pCtx ==  NULL) {
+        if (pCtx == NULL) {
                 imb_set_errno(NULL, IMB_ERR_NULL_EXP_KEY);
                 return;
         }
@@ -110,14 +105,12 @@ kasumi_f8_1_buffer_bit_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV,
                 return;
         }
         /* Check input data is in range of supported length */
-        if (cipherLengthInBits == 0 ||
-            cipherLengthInBits > KASUMI_MAX_LEN) {
+        if (cipherLengthInBits == 0 || cipherLengthInBits > KASUMI_MAX_LEN) {
                 imb_set_errno(NULL, IMB_ERR_CIPH_LEN);
                 return;
         }
 #endif
-        kasumi_f8_1_buffer_bit(pCtx, IV, pBufferIn, pBufferOut,
-                               cipherLengthInBits, offsetInBits);
+        kasumi_f8_1_buffer_bit(pCtx, IV, pBufferIn, pBufferOut, cipherLengthInBits, offsetInBits);
 #ifdef SAFE_DATA
         /* Clear sensitive data in registers */
         CLEAR_SCRATCH_GPS();
@@ -129,11 +122,9 @@ kasumi_f8_1_buffer_bit_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV,
 }
 
 void
-kasumi_f8_2_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV1,
-                       const uint64_t IV2, const void *pBufferIn1,
-                       void *pBufferOut1, const uint32_t lengthInBytes1,
-                       const void *pBufferIn2, void *pBufferOut2,
-                       const uint32_t lengthInBytes2)
+kasumi_f8_2_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV1, const uint64_t IV2,
+                       const void *pBufferIn1, void *pBufferOut1, const uint32_t lengthInBytes1,
+                       const void *pBufferIn2, void *pBufferOut2, const uint32_t lengthInBytes2)
 {
 #ifndef LINUX
         DECLARE_ALIGNED(imb_uint128_t xmm_save[10], 16);
@@ -143,7 +134,7 @@ kasumi_f8_2_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV1,
 #ifdef SAFE_PARAM
         /* Check for NULL pointers */
         imb_set_errno(NULL, 0);
-        if (pCtx ==  NULL) {
+        if (pCtx == NULL) {
                 imb_set_errno(NULL, IMB_ERR_NULL_EXP_KEY);
                 return;
         }
@@ -156,21 +147,18 @@ kasumi_f8_2_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV1,
                 return;
         }
         /* Check input data is in range of supported length */
-        if (lengthInBytes1 == 0 ||
-            lengthInBytes1 > (KASUMI_MAX_LEN / CHAR_BIT)) {
+        if (lengthInBytes1 == 0 || lengthInBytes1 > (KASUMI_MAX_LEN / CHAR_BIT)) {
                 imb_set_errno(NULL, IMB_ERR_CIPH_LEN);
                 return;
         }
 
-        if (lengthInBytes2 == 0 ||
-            lengthInBytes2 > (KASUMI_MAX_LEN / CHAR_BIT)) {
+        if (lengthInBytes2 == 0 || lengthInBytes2 > (KASUMI_MAX_LEN / CHAR_BIT)) {
                 imb_set_errno(NULL, IMB_ERR_CIPH_LEN);
                 return;
         }
 #endif
-        kasumi_f8_2_buffer(pCtx, IV1, IV2,
-                           pBufferIn1, pBufferOut1, lengthInBytes1,
-                           pBufferIn2, pBufferOut2, lengthInBytes2);
+        kasumi_f8_2_buffer(pCtx, IV1, IV2, pBufferIn1, pBufferOut1, lengthInBytes1, pBufferIn2,
+                           pBufferOut2, lengthInBytes2);
 #ifdef SAFE_DATA
         /* Clear sensitive data in registers */
         CLEAR_SCRATCH_GPS();
@@ -182,12 +170,10 @@ kasumi_f8_2_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV1,
 }
 
 void
-kasumi_f8_3_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV1,
-                       const uint64_t IV2, const uint64_t IV3,
-                       const void *pBufferIn1, void *pBufferOut1,
-                       const void *pBufferIn2, void *pBufferOut2,
-                       const void *pBufferIn3, void *pBufferOut3,
-                       const uint32_t lengthInBytes)
+kasumi_f8_3_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV1, const uint64_t IV2,
+                       const uint64_t IV3, const void *pBufferIn1, void *pBufferOut1,
+                       const void *pBufferIn2, void *pBufferOut2, const void *pBufferIn3,
+                       void *pBufferOut3, const uint32_t lengthInBytes)
 {
 #ifndef LINUX
         DECLARE_ALIGNED(imb_uint128_t xmm_save[10], 16);
@@ -197,7 +183,7 @@ kasumi_f8_3_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV1,
 #ifdef SAFE_PARAM
         /* Check for NULL pointers */
         imb_set_errno(NULL, 0);
-        if (pCtx ==  NULL) {
+        if (pCtx == NULL) {
                 imb_set_errno(NULL, IMB_ERR_NULL_EXP_KEY);
                 return;
         }
@@ -215,9 +201,7 @@ kasumi_f8_3_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV1,
                 return;
         }
 #endif
-        kasumi_f8_3_buffer(pCtx, IV1, IV2, IV3,
-                           pBufferIn1, pBufferOut1,
-                           pBufferIn2, pBufferOut2,
+        kasumi_f8_3_buffer(pCtx, IV1, IV2, IV3, pBufferIn1, pBufferOut1, pBufferIn2, pBufferOut2,
                            pBufferIn3, pBufferOut3, lengthInBytes);
 #ifdef SAFE_DATA
         /* Clear sensitive data in registers */
@@ -230,14 +214,11 @@ kasumi_f8_3_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV1,
 }
 
 void
-kasumi_f8_4_buffer_avx(const kasumi_key_sched_t *pCtx,
-                       const uint64_t IV1, const uint64_t IV2,
-                       const uint64_t IV3, const uint64_t IV4,
-                       const void *pBufferIn1, void *pBufferOut1,
-                       const void *pBufferIn2, void *pBufferOut2,
-                       const void *pBufferIn3, void *pBufferOut3,
-                       const void *pBufferIn4, void *pBufferOut4,
-                       const uint32_t lengthInBytes)
+kasumi_f8_4_buffer_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV1, const uint64_t IV2,
+                       const uint64_t IV3, const uint64_t IV4, const void *pBufferIn1,
+                       void *pBufferOut1, const void *pBufferIn2, void *pBufferOut2,
+                       const void *pBufferIn3, void *pBufferOut3, const void *pBufferIn4,
+                       void *pBufferOut4, const uint32_t lengthInBytes)
 {
 #ifndef LINUX
         DECLARE_ALIGNED(imb_uint128_t xmm_save[10], 16);
@@ -247,12 +228,11 @@ kasumi_f8_4_buffer_avx(const kasumi_key_sched_t *pCtx,
 #ifdef SAFE_PARAM
         /* Check for NULL pointers */
         imb_set_errno(NULL, 0);
-        if (pCtx ==  NULL) {
+        if (pCtx == NULL) {
                 imb_set_errno(NULL, IMB_ERR_NULL_EXP_KEY);
                 return;
         }
-        if (pBufferIn1 == NULL || pBufferIn2 == NULL || pBufferIn3 == NULL ||
-            pBufferIn4 == NULL) {
+        if (pBufferIn1 == NULL || pBufferIn2 == NULL || pBufferIn3 == NULL || pBufferIn4 == NULL) {
                 imb_set_errno(NULL, IMB_ERR_NULL_SRC);
                 return;
         }
@@ -267,11 +247,8 @@ kasumi_f8_4_buffer_avx(const kasumi_key_sched_t *pCtx,
                 return;
         }
 #endif
-        kasumi_f8_4_buffer(pCtx, IV1, IV2, IV3, IV4,
-                           pBufferIn1, pBufferOut1,
-                           pBufferIn2, pBufferOut2,
-                           pBufferIn3, pBufferOut3,
-                           pBufferIn4, pBufferOut4,
+        kasumi_f8_4_buffer(pCtx, IV1, IV2, IV3, IV4, pBufferIn1, pBufferOut1, pBufferIn2,
+                           pBufferOut2, pBufferIn3, pBufferOut3, pBufferIn4, pBufferOut4,
                            lengthInBytes);
 #ifdef SAFE_DATA
         /* Clear sensitive data in registers */
@@ -284,10 +261,9 @@ kasumi_f8_4_buffer_avx(const kasumi_key_sched_t *pCtx,
 }
 
 void
-kasumi_f8_n_buffer_avx(const kasumi_key_sched_t *pKeySchedule,
-                       const uint64_t IV[],
-                       const void * const pDataIn[], void *pDataOut[],
-                       const uint32_t dataLen[], const uint32_t dataCount)
+kasumi_f8_n_buffer_avx(const kasumi_key_sched_t *pKeySchedule, const uint64_t IV[],
+                       const void *const pDataIn[], void *pDataOut[], const uint32_t dataLen[],
+                       const uint32_t dataCount)
 {
 #ifndef LINUX
         DECLARE_ALIGNED(imb_uint128_t xmm_save[10], 16);
@@ -324,7 +300,7 @@ kasumi_f8_n_buffer_avx(const kasumi_key_sched_t *pKeySchedule,
 
         for (i = 0; i < dataCount; i++) {
                 /* Check for NULL pointers */
-                if (pDataIn[i] == NULL ) {
+                if (pDataIn[i] == NULL) {
                         imb_set_errno(NULL, IMB_ERR_NULL_SRC);
                         return;
                 }
@@ -333,8 +309,7 @@ kasumi_f8_n_buffer_avx(const kasumi_key_sched_t *pKeySchedule,
                         return;
                 }
                 /* Check input data is in range of supported length */
-                if (dataLen[i] == 0 ||
-                    dataLen[i] > (KASUMI_MAX_LEN / CHAR_BIT)) {
+                if (dataLen[i] == 0 || dataLen[i] > (KASUMI_MAX_LEN / CHAR_BIT)) {
                         imb_set_errno(NULL, IMB_ERR_CIPH_LEN);
                         return;
                 }
@@ -346,13 +321,13 @@ kasumi_f8_n_buffer_avx(const kasumi_key_sched_t *pKeySchedule,
         /* KASUMI F8 n buffer function can handle up to 16 buffers */
         while (numLeft > 0) {
                 const uint64_t *IVPtr = &IV[i];
-                const void * const *pDataInPtr = &pDataIn[i];
+                const void *const *pDataInPtr = &pDataIn[i];
                 void **pDataOutPtr = &pDataOut[i];
                 const uint32_t *dataLenPtr = &dataLen[i];
                 const uint32_t numBuffs = (numLeft > 16) ? 16 : numLeft;
 
-                kasumi_f8_n_buffer(pKeySchedule, IVPtr, pDataInPtr, pDataOutPtr,
-                                   dataLenPtr, numBuffs);
+                kasumi_f8_n_buffer(pKeySchedule, IVPtr, pDataInPtr, pDataOutPtr, dataLenPtr,
+                                   numBuffs);
                 i += numBuffs;
                 numLeft -= numBuffs;
         }
@@ -366,7 +341,6 @@ kasumi_f8_n_buffer_avx(const kasumi_key_sched_t *pKeySchedule,
 #endif
 }
 
-
 void
 kasumi_f9_1_buffer_avx(const kasumi_key_sched_t *pCtx, const void *pBufferIn,
                        const uint32_t lengthInBytes, void *pDigest)
@@ -412,8 +386,8 @@ kasumi_f9_1_buffer_avx(const kasumi_key_sched_t *pCtx, const void *pBufferIn,
 
 void
 kasumi_f9_1_buffer_user_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV,
-                            const void *pBufferIn, const uint32_t lengthInBits,
-                            void *pDigest, const uint32_t direction)
+                            const void *pBufferIn, const uint32_t lengthInBits, void *pDigest,
+                            const uint32_t direction)
 {
 #ifndef LINUX
         DECLARE_ALIGNED(imb_uint128_t xmm_save[10], 16);
@@ -443,8 +417,7 @@ kasumi_f9_1_buffer_user_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV,
                 return;
         }
 #endif
-        kasumi_f9_1_buffer_user(pCtx, IV, pBufferIn, lengthInBits,
-                                pDigest, direction);
+        kasumi_f9_1_buffer_user(pCtx, IV, pBufferIn, lengthInBits, pDigest, direction);
 #ifdef SAFE_DATA
         /* Clear sensitive data in registers */
         CLEAR_SCRATCH_GPS();
@@ -456,15 +429,13 @@ kasumi_f9_1_buffer_user_avx(const kasumi_key_sched_t *pCtx, const uint64_t IV,
 }
 
 int
-kasumi_init_f8_key_sched_avx(const void *const pKey,
-                             kasumi_key_sched_t *pCtx)
+kasumi_init_f8_key_sched_avx(const void *const pKey, kasumi_key_sched_t *pCtx)
 {
         return kasumi_init_f8_key_sched(pKey, pCtx);
 }
 
 int
-kasumi_init_f9_key_sched_avx(const void *const pKey,
-                             kasumi_key_sched_t *pCtx)
+kasumi_init_f9_key_sched_avx(const void *const pKey, kasumi_key_sched_t *pCtx)
 {
         return kasumi_init_f9_key_sched(pKey, pCtx);
 }
