@@ -41,16 +41,13 @@
  * @param job description of performed crypto operation
  * @return It always returns value passed in \a job
  */
-__forceinline
-IMB_JOB *
+__forceinline IMB_JOB *
 DES_CBC_ENC(IMB_JOB *job)
 {
         IMB_ASSERT(!(job->status & IMB_STATUS_COMPLETED_CIPHER));
-        des_enc_cbc_basic(job->src + job->cipher_start_src_offset_in_bytes,
-                          job->dst,
-                          job->msg_len_to_cipher_in_bytes &
-                          (~(IMB_DES_BLOCK_SIZE - 1)),
-                          job->enc_keys, (const uint64_t *)job->iv);
+        des_enc_cbc_basic(job->src + job->cipher_start_src_offset_in_bytes, job->dst,
+                          job->msg_len_to_cipher_in_bytes & (~(IMB_DES_BLOCK_SIZE - 1)),
+                          job->enc_keys, (const uint64_t *) job->iv);
         job->status |= IMB_STATUS_COMPLETED_CIPHER;
         return job;
 }
@@ -61,16 +58,13 @@ DES_CBC_ENC(IMB_JOB *job)
  * @param job description of performed crypto operation
  * @return It always returns value passed in \a job
  */
-__forceinline
-IMB_JOB *
+__forceinline IMB_JOB *
 DES_CBC_DEC(IMB_JOB *job)
 {
         IMB_ASSERT(!(job->status & IMB_STATUS_COMPLETED_CIPHER));
-        des_dec_cbc_basic(job->src + job->cipher_start_src_offset_in_bytes,
-                          job->dst,
-                          job->msg_len_to_cipher_in_bytes &
-                          (~(IMB_DES_BLOCK_SIZE - 1)),
-                          job->dec_keys, (const uint64_t *)job->iv);
+        des_dec_cbc_basic(job->src + job->cipher_start_src_offset_in_bytes, job->dst,
+                          job->msg_len_to_cipher_in_bytes & (~(IMB_DES_BLOCK_SIZE - 1)),
+                          job->dec_keys, (const uint64_t *) job->iv);
         job->status |= IMB_STATUS_COMPLETED_CIPHER;
         return job;
 }
@@ -81,20 +75,15 @@ DES_CBC_DEC(IMB_JOB *job)
  * @param job description of performed crypto operation
  * @return It always returns value passed in \a job
  */
-__forceinline
-IMB_JOB *
+__forceinline IMB_JOB *
 DES3_CBC_ENC(IMB_JOB *job)
 {
-        const void * const *ks_ptr =
-                (const void * const *)job->enc_keys;
+        const void *const *ks_ptr = (const void *const *) job->enc_keys;
 
         IMB_ASSERT(!(job->status & IMB_STATUS_COMPLETED_CIPHER));
-        des3_enc_cbc_basic(job->src + job->cipher_start_src_offset_in_bytes,
-                           job->dst,
-                           job->msg_len_to_cipher_in_bytes &
-                           (~(IMB_DES_BLOCK_SIZE - 1)),
-                           ks_ptr[0], ks_ptr[1], ks_ptr[2],
-                           (const uint64_t *)job->iv);
+        des3_enc_cbc_basic(job->src + job->cipher_start_src_offset_in_bytes, job->dst,
+                           job->msg_len_to_cipher_in_bytes & (~(IMB_DES_BLOCK_SIZE - 1)), ks_ptr[0],
+                           ks_ptr[1], ks_ptr[2], (const uint64_t *) job->iv);
         job->status |= IMB_STATUS_COMPLETED_CIPHER;
         return job;
 }
@@ -105,23 +94,17 @@ DES3_CBC_ENC(IMB_JOB *job)
  * @param job description of performed crypto operation
  * @return It always returns value passed in \a job
  */
-__forceinline
-IMB_JOB *
+__forceinline IMB_JOB *
 DES3_CBC_DEC(IMB_JOB *job)
 {
-        const void * const *ks_ptr =
-                (const void * const *)job->dec_keys;
+        const void *const *ks_ptr = (const void *const *) job->dec_keys;
 
         IMB_ASSERT(!(job->status & IMB_STATUS_COMPLETED_CIPHER));
-        des3_dec_cbc_basic(job->src + job->cipher_start_src_offset_in_bytes,
-                           job->dst,
-                           job->msg_len_to_cipher_in_bytes &
-                           (~(IMB_DES_BLOCK_SIZE - 1)),
-                           ks_ptr[0], ks_ptr[1], ks_ptr[2],
-                           (const uint64_t *)job->iv);
+        des3_dec_cbc_basic(job->src + job->cipher_start_src_offset_in_bytes, job->dst,
+                           job->msg_len_to_cipher_in_bytes & (~(IMB_DES_BLOCK_SIZE - 1)), ks_ptr[0],
+                           ks_ptr[1], ks_ptr[2], (const uint64_t *) job->iv);
         job->status |= IMB_STATUS_COMPLETED_CIPHER;
         return job;
 }
 
-
 #endif /* IMB_DES_H */
