@@ -35,11 +35,11 @@
 #include <intrin.h>
 #endif
 
-#define NUM_PACKETS_1 1
-#define NUM_PACKETS_2 2
-#define NUM_PACKETS_3 3
-#define NUM_PACKETS_4 4
-#define NUM_PACKETS_8 8
+#define NUM_PACKETS_1  1
+#define NUM_PACKETS_2  2
+#define NUM_PACKETS_3  3
+#define NUM_PACKETS_4  4
+#define NUM_PACKETS_8  8
 #define NUM_PACKETS_16 16
 
 #ifdef LINUX
@@ -65,28 +65,28 @@ typedef union _m64_u {
         uint64_t m;
 } m64_t;
 
-static inline uint32_t bswap4(const uint32_t val)
+static inline uint32_t
+bswap4(const uint32_t val)
 {
         return BSWAP32(val);
 }
 
 /*************************************************************************
-* @description - this function is used to copy the right number of bytes
-*                from the source to destination buffer
-*
-* @param pSrc [IN] - pointer to an input Byte array (at least len bytes
-*                    available)
-* @param pDst [IN] - pointer to the output buffer (at least len bytes available)
-* @param len  [IN] - length in bytes to copy (0 to 4)
-*
-*************************************************************************/
-static inline void memcpy_keystream_32(uint8_t *pDst,
-                                       const uint8_t *pSrc,
-                                       const uint32_t len)
+ * @description - this function is used to copy the right number of bytes
+ *                from the source to destination buffer
+ *
+ * @param pSrc [IN] - pointer to an input Byte array (at least len bytes
+ *                    available)
+ * @param pDst [IN] - pointer to the output buffer (at least len bytes available)
+ * @param len  [IN] - length in bytes to copy (0 to 4)
+ *
+ *************************************************************************/
+static inline void
+memcpy_keystream_32(uint8_t *pDst, const uint8_t *pSrc, const uint32_t len)
 {
         switch (len) {
         case 4:
-                *(uint32_t *)pDst = *(const uint32_t *)pSrc;
+                *(uint32_t *) pDst = *(const uint32_t *) pSrc;
                 break;
         case 3:
                 pDst[2] = pSrc[2];
@@ -101,20 +101,19 @@ static inline void memcpy_keystream_32(uint8_t *pDst,
 }
 
 /*************************************************************************
-* @description - this function is used to XOR the right number of bytes
-*                from a keystrea and a source into a destination buffer
-*
-* @param pSrc [IN] - pointer to an input Byte array (at least 4 bytes available)
-* @param pDst [IN] - pointer to the output buffer (at least 4 bytes available)
-* @param KS  [IN]  - 4 bytes of keystream number, must be reversed
-*                    into network byte order before XOR
-*
-*************************************************************************/
-static inline void xor_keystream_reverse_32(uint8_t *pDst,
-                                            const uint8_t *pSrc,
-                                            const uint32_t KS)
+ * @description - this function is used to XOR the right number of bytes
+ *                from a keystrea and a source into a destination buffer
+ *
+ * @param pSrc [IN] - pointer to an input Byte array (at least 4 bytes available)
+ * @param pDst [IN] - pointer to the output buffer (at least 4 bytes available)
+ * @param KS  [IN]  - 4 bytes of keystream number, must be reversed
+ *                    into network byte order before XOR
+ *
+ *************************************************************************/
+static inline void
+xor_keystream_reverse_32(uint8_t *pDst, const uint8_t *pSrc, const uint32_t KS)
 {
-        *(uint32_t *)pDst = (*(const uint32_t *)pSrc) ^ BSWAP32(KS);
+        *(uint32_t *) pDst = (*(const uint32_t *) pSrc) ^ BSWAP32(KS);
 }
 
 /******************************************************************************
@@ -128,10 +127,10 @@ static inline const uint8_t *
 xor_keystrm_rev(uint8_t *pDst, const uint8_t *pSrc, uint64_t keyStream)
 {
         /* default: XOR ONLY, read the input buffer, update the output buffer */
-        const uint64_t *pSrc64 = (const uint64_t *)pSrc;
-        uint64_t *pDst64 = (uint64_t *)pDst;
+        const uint64_t *pSrc64 = (const uint64_t *) pSrc;
+        uint64_t *pDst64 = (uint64_t *) pDst;
         *pDst64 = *pSrc64 ^ BSWAP64(keyStream);
-        return (const uint8_t *)(pSrc64 + 1);
+        return (const uint8_t *) (pSrc64 + 1);
 }
 
 /******************************************************************************
@@ -148,7 +147,7 @@ memcpy_keystrm(uint8_t *pDst, const uint8_t *pSrc, const uint32_t len)
 {
         switch (len) {
         case 8:
-                *(uint64_t *)pDst = *(const uint64_t *)pSrc;
+                *(uint64_t *) pDst = *(const uint64_t *) pSrc;
                 break;
         case 7:
                 pDst[6] = pSrc[6];
@@ -160,7 +159,7 @@ memcpy_keystrm(uint8_t *pDst, const uint8_t *pSrc, const uint32_t len)
                 pDst[4] = pSrc[4];
                 /* fall-through */
         case 4:
-                *(uint32_t *)pDst = *(const uint32_t *)pSrc;
+                *(uint32_t *) pDst = *(const uint32_t *) pSrc;
                 break;
         case 3:
                 pDst[2] = pSrc[2];
@@ -178,37 +177,38 @@ memcpy_keystrm(uint8_t *pDst, const uint8_t *pSrc, const uint32_t len)
  * @brief Save start and end of the buffer around message
  *
  * @param msg message buffer (destination buffer)
- * @param bit_offset message offset in bits
+ * @param bit_offset message offset in bits (0- 7)
  * @param bit_length message length in bits
  * @param save_start place to store start byte
  * @param save_end place to store end byte
  */
 static inline void
-save_msg_start_end(const void *msg,
-                   const size_t bit_offset, const size_t bit_length,
+msg_save_start_end(const void *msg, const size_t bit_offset, const size_t bit_length,
                    uint8_t *save_start, uint8_t *save_end)
 {
-        const uint8_t *msg_ptr = (const uint8_t *) msg;
-        const size_t mstart_bit = bit_offset & 7; /* inclusive */
-        const size_t mend_bit =
-                (mstart_bit + bit_length) & 7; /* non-inclusive */
-
         *save_start = 0;
         *save_end = 0;
 
-        if (bit_length == 0)
+        if (bit_length == 0 || bit_offset == 0)
                 return;
 
-        if (mstart_bit != 0) {
-                const uint8_t msg_start = msg_ptr[bit_offset >> 3];
+        /* 0xff << (8 - i) */
+        static const uint8_t mtab_shl[8] = { 0x00, 0x80, 0xc0, 0xe0, 0xf0, 0xf8, 0xfc, 0xfe };
+        const uint8_t *msg_ptr = (const uint8_t *) msg;
 
-                *save_start = msg_start & (0xff << (8 - mstart_bit));
-        }
+        *save_start = *msg_ptr & mtab_shl[bit_offset];
 
-        if (mend_bit != 0) {
-                const uint8_t msg_end = msg_ptr[(bit_offset + bit_length) >> 3];
+        /* 0xff >> i */
+        static const uint8_t mtab_shr[8] = { 0xff, 0x7f, 0x3f, 0x1f, 0x0f, 0x07, 0x03, 0x01 };
+        const size_t blast = bit_offset + bit_length;
+        const size_t bend = blast & 7; /* non-inclusive */
 
-                *save_end = msg_end & (0xff >> mend_bit);
+        if (blast < 8) {
+                *save_end = msg_ptr[0] & mtab_shr[bend];
+        } else {
+                const size_t i = ((bend == 0) ? (blast - 8) : blast) / 8;
+
+                *save_end = msg_ptr[i] & mtab_shr[bend];
         }
 }
 
@@ -222,63 +222,87 @@ save_msg_start_end(const void *msg,
  * @param save_end saved end byte to be restored
  */
 static inline void
-restore_msg_start_end(void *msg,
-                      const size_t bit_offset, const size_t bit_length,
+msg_restore_start_end(void *msg, const size_t bit_offset, const size_t bit_length,
                       const uint8_t save_start, const uint8_t save_end)
 {
-        uint8_t *msg_ptr = (uint8_t *) msg;
-
-        if (bit_length == 0)
+        if (bit_length == 0 || bit_offset == 0)
                 return;
 
+        uint8_t *msg_ptr = (uint8_t *) msg;
+
         if (save_start != 0)
                 msg_ptr[bit_offset >> 3] |= save_start;
 
-        if (save_end != 0)
-                msg_ptr[(bit_offset + bit_length) >> 3] |= save_end;
+        if (save_end != 0) {
+                const size_t blast = bit_offset + bit_length;
+
+                if (blast < 8) {
+                        msg_ptr[0] |= save_end;
+                } else {
+                        const size_t bend = blast & 7; /* non-inclusive */
+                        const size_t i = ((bend == 0) ? (blast - 8) : blast) / 8;
+
+                        msg_ptr[i] |= save_end;
+                }
+        }
 }
 
 /**
  * @brief Copy bit message from \a src to \dst
  *
+ * When reading data from \a src, shift left \a src by \a src_bit_offset number bits
+ *
  * @param dst destination buffer
  * @param src source buffer
- * @param bit_offset offset from in bits from \a src
+ * @param src_bit_offset offset from in bits from \a src (0 - 7)
  * @param bit_length message length in bits
  */
 static inline void
-copy_bits(void *dst, const void *src,
-          const size_t bit_offset, const size_t bit_length)
+msg_shl_copy(void *dst, const void *src, const size_t src_bit_offset, const size_t bit_length)
 {
         uint8_t *dp = (uint8_t *) dst;
-        const uint8_t *sp = &((const uint8_t *) src)[bit_offset >> 3];
-        const size_t mstart_bit = bit_offset & 7;
-        const size_t mend_bit = (bit_offset + bit_length) & 7;
-        size_t byte_length = (bit_length + 7) >> 3;
+        const uint8_t *sp = (const uint8_t *) src;
 
-        if (bit_length == 0)
-                return;
+        const size_t bit_start = src_bit_offset;
+        const size_t byte_length = bit_length / 8;
 
-        for ( ; byte_length >= 1; byte_length--) {
-                if (mstart_bit == 0) {
-                        *dp++ = *sp++;
+        size_t i;
+
+        for (i = 0; i < byte_length; i++) {
+                if (bit_start == 0) {
+                        dp[i] = sp[i];
                 } else {
-                        *dp++ = (sp[0] << mstart_bit) |
-                                (sp[1] >> (8 - mstart_bit));
-                        sp++;
+                        const uint8_t nibble1 = sp[i] << bit_start;
+                        const uint8_t nibble2 = sp[i + 1] >> (8 - bit_start);
+
+                        dp[i] = nibble1 | nibble2;
                 }
         }
 
-        if (mstart_bit == 0) {
-                if (mend_bit == 0)
-                        *dp = *sp;
-                else
-                        *dp = *sp & (0xff << (8 - mend_bit));
-        } else {
-                if (mend_bit == 0)
-                        *dp = *sp << mstart_bit;
-                else
-                        *dp = (*sp & (0xff << (8 - mend_bit))) << mstart_bit;
+        const size_t last_byte_bits = bit_length & 7;
+
+        if (last_byte_bits != 0) {
+                if (bit_start == 0) {
+                        dp[i] = sp[i];
+                } else {
+                        if (last_byte_bits <= (8 - bit_start)) {
+                                const uint8_t nibble = sp[i] << bit_start;
+
+                                dp[i] = nibble;
+                        } else {
+                                const uint8_t nibble1 = sp[i] << bit_start;
+                                const uint8_t nibble2 = sp[i + 1] >> (8 - bit_start);
+
+                                dp[i] = nibble1 | nibble2;
+                        }
+                }
+
+                /* 0xff << (8 - i) */
+                static const uint8_t mtab_shl[8] = {
+                        0x00, 0x80, 0xc0, 0xe0, 0xf0, 0xf8, 0xfc, 0xfe
+                };
+
+                dp[i] = dp[i] & mtab_shl[last_byte_bits];
         }
 }
 
@@ -294,42 +318,37 @@ copy_bits(void *dst, const void *src,
  * 00A7A6A5A4A3A2A1 A0B7B6B5B4B3B2B1 B0
  *
  * @param msg message buffer
- * @param bit_offset number of bits to shift \a msg right by
+ * @param bit_offset number of bits to shift \a msg right by (0 to 7)
  * @param bit_length message length in bits
  */
 static inline void
-shift_bits(void *msg, const size_t bit_offset, const size_t bit_length)
+msg_shr(void *msg, const size_t nbits, const size_t bit_length)
 {
-        uint8_t *dst = (uint8_t *) msg;
-        const size_t mstart_bit = bit_offset & 7;
-        const size_t mend_bit = (bit_offset + bit_length) & 7;
-        size_t byte_length = (bit_length + 7) >> 3;
-
-        if (bit_length == 0)
+        if (nbits == 0 || bit_length == 0)
                 return;
 
-        if (mstart_bit != 0) {
-                uint8_t byte_save = 0;
+        uint8_t *dp = (uint8_t *) msg;
+        const size_t byte_length = bit_length / 8;
+        uint8_t carry = 0;
+        size_t i;
 
-                if (byte_length == 1) {
-                        *dst = (*dst & (0xff << (8 - mend_bit))) >> mstart_bit;
-                        return;
-                }
+        for (i = 0; i < byte_length; i++) {
+                const uint8_t nibble = dp[i];
 
-                for ( ; byte_length >= 1; byte_length--) {
-                        const uint8_t c = *dst;
-
-                        *dst++ = (c >> mstart_bit) | byte_save;
-                        byte_save = c << (8 - mstart_bit);
-                }
-
-                *dst = byte_save;
-        } else {
-                if (mend_bit != 0)
-                        dst[byte_length] &= (0xff << (8 - mend_bit));
+                dp[i] = (carry << (8 - nbits)) | (nibble >> nbits);
+                carry = nibble;
         }
-}
 
+        /* 0xff << (8 - i) */
+        static const uint8_t mtab_shl[8] = { 0x00, 0x80, 0xc0, 0xe0, 0xf0, 0xf8, 0xfc, 0xfe };
+        const size_t last_byte_bits = bit_length & 7;
+        const uint8_t nibble = (last_byte_bits != 0) ? (dp[i] & mtab_shl[last_byte_bits]) : 0;
+
+        dp[i] = (carry << (8 - nbits)) | (nibble >> nbits);
+
+        if ((last_byte_bits + nbits) > 8)
+                dp[i + 1] = nibble << (8 - nbits);
+}
 
 /**
  ******************************************************************************
@@ -346,8 +365,8 @@ shift_bits(void *msg, const size_t bit_offset, const size_t bit_length)
  *      None
  *
  *****************************************************************************/
-IMB_DLL_LOCAL void asm_XorKeyStream16B_sse(const void *pIn, void *pOut,
-                                           const void *pKey);
+IMB_DLL_LOCAL void
+asm_XorKeyStream16B_sse(const void *pIn, void *pOut, const void *pKey);
 
 /**
  ******************************************************************************
@@ -364,8 +383,8 @@ IMB_DLL_LOCAL void asm_XorKeyStream16B_sse(const void *pIn, void *pOut,
  *      None
  *
  *****************************************************************************/
-IMB_DLL_LOCAL void asm_XorKeyStream16B_avx(const void *pIn, void *pOut,
-                                           const void *pKey);
+IMB_DLL_LOCAL void
+asm_XorKeyStream16B_avx(const void *pIn, void *pOut, const void *pKey);
 
 /**
  ******************************************************************************
@@ -382,8 +401,8 @@ IMB_DLL_LOCAL void asm_XorKeyStream16B_avx(const void *pIn, void *pOut,
  *      None
  *
  *****************************************************************************/
-IMB_DLL_LOCAL void asm_XorKeyStream32B_avx2(const void *pIn, void *pOut,
-                                            const void *pKey);
+IMB_DLL_LOCAL void
+asm_XorKeyStream32B_avx2(const void *pIn, void *pOut, const void *pKey);
 
 /**
  ******************************************************************************
@@ -400,7 +419,7 @@ IMB_DLL_LOCAL void asm_XorKeyStream32B_avx2(const void *pIn, void *pOut,
  *      None
  *
  *****************************************************************************/
-IMB_DLL_LOCAL void asm_XorKeyStream64B_avx512(const void *pIn, void *pOut,
-                                              const void *pKey);
+IMB_DLL_LOCAL void
+asm_XorKeyStream64B_avx512(const void *pIn, void *pOut, const void *pKey);
 
 #endif /* _WIRELESS_COMMON_H_ */
