@@ -26,21 +26,22 @@
 *******************************************************************************/
 
 #define SSE
-#define SNOW3G_F8_1_BUFFER_BIT snow3g_f8_1_buffer_bit_sse
-#define SNOW3G_F8_1_BUFFER snow3g_f8_1_buffer_sse
-#define SNOW3G_F8_2_BUFFER snow3g_f8_2_buffer_sse
-#define SNOW3G_F8_4_BUFFER snow3g_f8_4_buffer_sse
-#define SNOW3G_F8_8_BUFFER snow3g_f8_8_buffer_sse
-#define SNOW3G_F8_N_BUFFER snow3g_f8_n_buffer_sse
+#define SNOW3G_F8_1_BUFFER_BIT      snow3g_f8_1_buffer_bit_sse
+#define SNOW3G_F8_1_BUFFER          snow3g_f8_1_buffer_sse
+#define SNOW3G_F8_2_BUFFER          snow3g_f8_2_buffer_sse
+#define SNOW3G_F8_4_BUFFER          snow3g_f8_4_buffer_sse
+#define SNOW3G_F8_8_BUFFER          snow3g_f8_8_buffer_sse
+#define SNOW3G_F8_N_BUFFER          snow3g_f8_n_buffer_sse
 #define SNOW3G_F8_8_BUFFER_MULTIKEY snow3g_f8_8_buffer_multikey_sse
 #define SNOW3G_F8_N_BUFFER_MULTIKEY snow3g_f8_n_buffer_multikey_sse
-#define SNOW3G_F9_1_BUFFER snow3g_f9_1_buffer_sse
-#define SNOW3G_INIT_KEY_SCHED snow3g_init_key_sched_sse
-#define SNOW3G_KEY_SCHED_SIZE snow3g_key_sched_size_sse
-#define CLEAR_SCRATCH_SIMD_REGS clear_scratch_xmms_sse
+#define SNOW3G_F9_1_BUFFER          snow3g_f9_1_buffer_sse
+#define SNOW3G_INIT_KEY_SCHED       snow3g_init_key_sched_sse
+#define SNOW3G_KEY_SCHED_SIZE       snow3g_key_sched_size_sse
+#define CLEAR_SCRATCH_SIMD_REGS     clear_scratch_xmms_sse
 
 #include "include/snow3g_common.h"
 #include "include/ipsec_ooo_mgr.h"
 
-IMB_DLL_LOCAL void submit_job_snow3g_uea2_sse(MB_MGR_SNOW3G_OOO *, IMB_JOB *);
+IMB_DLL_LOCAL void
+submit_job_snow3g_uea2_sse(MB_MGR_SNOW3G_OOO *, IMB_JOB *);
 IMB_DLL_LOCAL void flush_job_snow3g_uea2_sse(MB_MGR_SNOW3G_OOO);
