@@ -2,7 +2,7 @@
 
 """
 **********************************************************************
-  Copyright(c) 2021-2022, Intel Corporation All rights reserved.
+  Copyright(c) 2021-2023, Intel Corporation All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
@@ -60,9 +60,9 @@ class Variant:
     """Class to setup and run test case variant"""
     def __init__(self, idx=None, arch=None, direction='encrypt', cipher_alg=None,
                  hash_alg=None, aead_alg=None, sizes=None, offset=None,
-                 cold_cache=False, shani_off=False, gcm_job_api=False,
+                 cold_cache=False, shani_off=False, force_job_api=False,
                  unhalted_cycles=False, quick_test=False, smoke_test=False,
-                 imix=None, aad_size=None, job_iter=None):
+                 imix=None, aad_size=None, job_iter=None, no_time_box=False, buffer_offset=None):
         """Build perf app command line"""
         global PERF_APP
 
@@ -80,13 +80,15 @@ class Variant:
         self.core = None
         self.cold_cache = cold_cache
         self.shani_off = shani_off
-        self.gcm_job_api = gcm_job_api
+        self.force_job_api = force_job_api
         self.unhalted_cycles = unhalted_cycles
         self.quick_test = quick_test
         self.smoke_test = smoke_test
         self.imix = imix
         self.aad_size = aad_size
         self.job_iter = job_iter
+        self.no_time_box = no_time_box
+        self.buffer_offset = buffer_offset
 
         if self.arch is not None:
             self.cmd += ' --arch {}'.format(self.arch)
@@ -127,8 +129,8 @@ class Variant:
         if self.shani_off is True:
             self.cmd += ' --shani-off'
 
-        if self.gcm_job_api is True:
-            self.cmd += ' --gcm-job-api'
+        if self.force_job_api is True:
+            self.cmd += ' --force-job-api'
 
         if self.unhalted_cycles is True:
             self.cmd += ' --unhalted-cycles'
@@ -139,6 +141,9 @@ class Variant:
         if self.smoke_test is True:
             self.cmd += ' --smoke'
 
+        if self.no_time_box is True:
+            self.cmd += ' --no-time-box'
+                
         if self.imix is not None:
             self.cmd += ' --imix {}'.format(self.imix)
 
@@ -148,6 +153,8 @@ class Variant:
         if self.job_iter is not None:
             self.cmd += ' --job-iter {}'.format(self.job_iter)
 
+        if self.buffer_offset is not None:
+            self.cmd += ' --buffer-offset {}'.format(self.buffer_offset)
 
     def run(self):
         """Run perf app and store output"""
@@ -254,9 +261,9 @@ def init_global_vars():
 
     # detect OS and select app name
     if platform.system() == 'Windows':
-        PERF_APP = 'ipsec_perf.exe'
+        PERF_APP = 'imb-perf.exe'
     else:
-        PERF_APP = 'ipsec_perf'
+        PERF_APP = 'imb-perf'
 
 
 def get_info():
@@ -355,7 +362,6 @@ def parse_args():
     global QUIET
     cores = None
     directions = ['encrypt', 'decrypt']
-    offset = 24
     alg_types = ['cipher-only', 'hash-only', 'aead-only', 'cipher-hash-all']
 
     parser = argparse.ArgumentParser(formatter_class=argparse.RawTextHelpFormatter,
@@ -370,8 +376,8 @@ def parse_args():
                         help="list/range of cores e.g. 2-8 or 3,4,5")
     parser.add_argument("-d", "--direction", default=None,
                         choices=directions, help="Cipher direction")
-    parser.add_argument("-o", "--offset", default=offset, type=int,
-                        help="offset for the SHA size increment, default is 24")
+    parser.add_argument("-o", "--offset", default=None, type=int,
+                        help="offset for the SHA size increment")
     parser.add_argument("-t", "--alg-type", default=None, action='append', choices=alg_types,
                         help="algorithm types to test")
     parser.add_argument("-s", "--job-size", default=None,
@@ -389,8 +395,8 @@ def parse_args():
     parser.add_argument("--arch-best", action='store_true',
                         help="detect available architectures and run only on the best one")
     parser.add_argument("--shani-off", action='store_true', help="don't use SHA extensions")
-    parser.add_argument("--gcm-job-api", action='store_true',
-                        help="use JOB API for GCM perf tests (raw GCM API is default)")
+    parser.add_argument("--force-job-api", action='store_true',
+                        help="use JOB API for algorithms supported through direct API (i.e. AES-GCM, chacha20-poly1305)")
     parser.add_argument("--unhalted-cycles", action='store_true',
                         help=textwrap.dedent('''\
                         measure using unhalted cycles (requires root).
@@ -415,7 +421,10 @@ def parse_args():
                         help="size of AAD for AEAD algorithms")
     parser.add_argument("--job-iter", default=None, type=int,
                         help="number of tests iterations for each job size")
-
+    parser.add_argument("--no-time-box", default=False, action='store_true',
+                        help="disables time box feature for single packet size test duration (100ms)")
+    parser.add_argument("--buffer-offset", default=None, type=int,
+                        help="buffer start address offset value 0-15, default 0")
 
     args = parser.parse_args()
 
@@ -452,9 +461,9 @@ def parse_args():
 
     return args.arch, cores, directions, args.offset, \
         alg_types, args.job_size, args.cold_cache, args.arch_best, \
-        args.shani_off, args.gcm_job_api, args.unhalted_cycles, \
+        args.shani_off, args.force_job_api, args.unhalted_cycles, \
         args.quick, args.smoke, args.imix, \
-        args.aad_size, args.job_iter
+        args.aad_size, args.job_iter, args.no_time_box, args.buffer_offset
 
 
 def run_test(core=None):
@@ -523,8 +532,8 @@ def main():
 
     # parse command line args
     archs, cores, directions, offset, alg_types, sizes, cold_cache, arch_best, \
-        shani_off, gcm_job_api, unhalted_cycles, quick_test, smoke_test, \
-        imix, aad_size, job_iter = parse_args()
+        shani_off, force_job_api, unhalted_cycles, quick_test, smoke_test, \
+        imix, aad_size, job_iter, no_time_box, buffer_offset = parse_args()
 
     # validate requested archs are supported
     if arch_best is True:
@@ -555,7 +564,7 @@ def main():
             print('  Cores: {}'.format(cores), file=sys.stderr)
         print('  Cache: {}'.format("cold" if cold_cache else "warm"), file=sys.stderr)
         print('  SHANI: {}'.format("off" if shani_off else "on"), file=sys.stderr)
-        print('  GCM API: {}'.format("job" if gcm_job_api else "direct"), file=sys.stderr)
+        print('  API: {}'.format("job" if force_job_api else "direct"), file=sys.stderr)
         print('  Measuring using {}'.format("unhalted cycles" if unhalted_cycles \
                                             else "rdtsc"), file=sys.stderr)
         if quick_test is True or smoke_test is True:
@@ -573,9 +582,10 @@ def main():
                     TODO_Q.put(Variant(idx=TOTAL_VARIANTS, arch=arch, direction=direction,
                                        offset=offset, sizes=sizes, cipher_alg=cipher_alg,
                                        cold_cache=cold_cache, shani_off=shani_off,
-                                       gcm_job_api=gcm_job_api, unhalted_cycles=unhalted_cycles,
+                                       force_job_api=force_job_api, unhalted_cycles=unhalted_cycles,
                                        quick_test=quick_test, smoke_test=smoke_test, imix=imix,
-                                       aad_size=aad_size, job_iter=job_iter))
+                                       aad_size=aad_size, job_iter=job_iter, no_time_box=no_time_box,
+				       buffer_offset=buffer_offset))
                     TOTAL_VARIANTS += 1
 
         if 'hash-only' in alg_types:
@@ -584,9 +594,10 @@ def main():
                 TODO_Q.put(Variant(idx=TOTAL_VARIANTS, arch=arch, direction=None,
                                    offset=offset, sizes=sizes, hash_alg=hash_alg,
                                    cold_cache=cold_cache, shani_off=shani_off,
-                                   gcm_job_api=gcm_job_api, unhalted_cycles=unhalted_cycles,
+                                   force_job_api=force_job_api, unhalted_cycles=unhalted_cycles,
                                    quick_test=quick_test, smoke_test=smoke_test, imix=imix,
-                                   aad_size=aad_size, job_iter=job_iter))
+                                   aad_size=aad_size, job_iter=job_iter, no_time_box=no_time_box,
+			       	   buffer_offset=buffer_offset))
                 TOTAL_VARIANTS += 1
 
         if 'aead-only' in alg_types:
@@ -595,9 +606,10 @@ def main():
                     TODO_Q.put(Variant(idx=TOTAL_VARIANTS, arch=arch, direction=direction,
                                        offset=offset, sizes=sizes, aead_alg=aead_alg,
                                        cold_cache=cold_cache, shani_off=shani_off,
-                                       gcm_job_api=gcm_job_api, unhalted_cycles=unhalted_cycles,
+                                       force_job_api=force_job_api, unhalted_cycles=unhalted_cycles,
                                        quick_test=quick_test, smoke_test=smoke_test, imix=imix,
-                                       aad_size=aad_size, job_iter=job_iter))
+                                       aad_size=aad_size, job_iter=job_iter, no_time_box=no_time_box,
+				       buffer_offset=buffer_offset))
                     TOTAL_VARIANTS += 1
 
         if 'cipher-hash-all' in alg_types:
@@ -608,10 +620,11 @@ def main():
                         TODO_Q.put(Variant(idx=TOTAL_VARIANTS, arch=arch, direction=direction,
                                            offset=offset, sizes=sizes, cipher_alg=cipher_alg,
                                            hash_alg=hash_alg, cold_cache=cold_cache,
-                                           shani_off=shani_off, gcm_job_api=gcm_job_api,
+                                           shani_off=shani_off, force_job_api=force_job_api,
                                            unhalted_cycles=unhalted_cycles, quick_test=quick_test,
                                            smoke_test=smoke_test, imix=imix, aad_size=aad_size,
-                                           job_iter=job_iter))
+                                           job_iter=job_iter, no_time_box=no_time_box,
+					   buffer_offset=buffer_offset))
                         TOTAL_VARIANTS += 1
 
     # take starting timestamp
