@@ -35,36 +35,84 @@
 #include "customop_test.h"
 #include "utils.h"
 
-extern int des_test(struct IMB_MGR *mb_mgr);
-extern int ccm_test(struct IMB_MGR *mb_mgr);
-extern int cmac_test(struct IMB_MGR *mb_mgr);
-extern int hmac_sha1_test(struct IMB_MGR *mb_mgr);
-extern int hmac_sha256_sha512_test(struct IMB_MGR *mb_mgr);
-extern int hmac_md5_test(struct IMB_MGR *mb_mgr);
-extern int aes_test(struct IMB_MGR *mb_mgr);
-extern int ecb_test(struct IMB_MGR *mb_mgr);
-extern int sha_test(struct IMB_MGR *mb_mgr);
-extern int chained_test(struct IMB_MGR *mb_mgr);
-extern int api_test(struct IMB_MGR *mb_mgr);
-extern int pon_test(struct IMB_MGR *mb_mgr);
-extern int zuc_test(struct IMB_MGR *mb_mgr);
-extern int kasumi_test(struct IMB_MGR *mb_mgr);
-extern int snow3g_test(struct IMB_MGR *mb_mgr);
-extern int direct_api_test(struct IMB_MGR *mb_mgr);
-extern int clear_mem_test(struct IMB_MGR *mb_mgr);
-extern int hec_test(struct IMB_MGR *mb_mgr);
-extern int xcbc_test(struct IMB_MGR *mb_mgr);
-extern int aes_cbcs_test(struct IMB_MGR *mb_mgr);
-extern int crc_test(struct IMB_MGR *mb_mgr);
-extern int chacha_test(struct IMB_MGR *mb_mgr);
-extern int poly1305_test(struct IMB_MGR *mb_mgr);
-extern int chacha20_poly1305_test(struct IMB_MGR *mb_mgr);
-extern int null_test(struct IMB_MGR *mb_mgr);
-extern int snow_v_test(struct IMB_MGR *mb_mgr);
-extern int direct_api_param_test(struct IMB_MGR *mb_mgr);
-extern int quic_ecb_test(struct IMB_MGR *mb_mgr);
-extern int gmac_test(struct IMB_MGR *mb_mgr);
-extern int ghash_test(struct IMB_MGR *mb_mgr);
+extern int
+des_test(struct IMB_MGR *mb_mgr);
+extern int
+ccm_test(struct IMB_MGR *mb_mgr);
+extern int
+cmac_test(struct IMB_MGR *mb_mgr);
+extern int
+hmac_sha1_test(struct IMB_MGR *mb_mgr);
+extern int
+hmac_sha256_sha512_test(struct IMB_MGR *mb_mgr);
+extern int
+hmac_md5_test(struct IMB_MGR *mb_mgr);
+extern int
+aes_test(struct IMB_MGR *mb_mgr);
+extern int
+ecb_test(struct IMB_MGR *mb_mgr);
+extern int
+sha_test(struct IMB_MGR *mb_mgr);
+extern int
+chained_test(struct IMB_MGR *mb_mgr);
+extern int
+api_test(struct IMB_MGR *mb_mgr);
+extern int
+pon_test(struct IMB_MGR *mb_mgr);
+extern int
+zuc_eea3_test(struct IMB_MGR *mb_mgr);
+extern int
+zuc_eia3_test(struct IMB_MGR *mb_mgr);
+extern int
+kasumi_test(struct IMB_MGR *mb_mgr);
+extern int
+snow3g_test(struct IMB_MGR *mb_mgr);
+extern int
+direct_api_test(struct IMB_MGR *mb_mgr);
+extern int
+clear_mem_test(struct IMB_MGR *mb_mgr);
+extern int
+hec_test(struct IMB_MGR *mb_mgr);
+extern int
+xcbc_test(struct IMB_MGR *mb_mgr);
+extern int
+aes_cbcs_test(struct IMB_MGR *mb_mgr);
+extern int
+crc_test(struct IMB_MGR *mb_mgr);
+extern int
+chacha_test(struct IMB_MGR *mb_mgr);
+extern int
+poly1305_test(struct IMB_MGR *mb_mgr);
+extern int
+chacha20_poly1305_test(struct IMB_MGR *mb_mgr);
+extern int
+null_test(struct IMB_MGR *mb_mgr);
+extern int
+snow_v_test(struct IMB_MGR *mb_mgr);
+extern int
+direct_api_param_test(struct IMB_MGR *mb_mgr);
+extern int
+quic_ecb_test(struct IMB_MGR *mb_mgr);
+extern int
+quic_chacha20_test(struct IMB_MGR *mb_mgr);
+extern int
+gmac_test(struct IMB_MGR *mb_mgr);
+extern int
+ghash_test(struct IMB_MGR *mb_mgr);
+extern int
+cbc_test(struct IMB_MGR *mb_mgr);
+extern int
+cfb_test(struct IMB_MGR *mb_mgr);
+extern int
+ctr_test(struct IMB_MGR *mb_mgr);
+extern int
+sm4_ecb_test(struct IMB_MGR *mb_mgr);
+extern int
+sm4_cbc_test(struct IMB_MGR *mb_mgr);
+extern int
+sm3_test(struct IMB_MGR *mb_mg);
+extern int
+hmac_sm3_test(struct IMB_MGR *mb_mg);
 
 typedef int (*imb_test_t)(struct IMB_MGR *mb_mgr);
 
@@ -74,193 +122,62 @@ typedef int (*imb_test_t)(struct IMB_MGR *mb_mgr);
 #define strcasecmp _stricmp
 #endif
 
-#define MAX_STR_LENGTH 32
-
 struct imb_test {
-        char str[MAX_STR_LENGTH];
+        const char *str;
         imb_test_t fn;
         unsigned enabled;
 };
 
 struct imb_test tests[] = {
-        {
-                .str = "KAT",
-                .fn = known_answer_test,
-                .enabled = 1
-        },
-        {
-                .str = "DO_TEST",
-                .fn = do_test,
-                .enabled = 1
-        },
-        {
-		.str = "CTR",
-                .fn = ctr_test,
-                .enabled = 1
-        },
-        {
-                .str = "PON",
-                .fn = pon_test,
-                .enabled = 1
-        },
-        {
-		.str = "XCBC",
-                .fn = xcbc_test,
-                .enabled = 1
-        },
-        {
-                .str = "GCM",
-                .fn = gcm_test,
-                .enabled = 1
-        },
-        {
-                .str = "GMAC",
-                .fn = gmac_test,
-                .enabled = 1
-        },
-        {
-                .str = "GHASH",
-                .fn = ghash_test,
-                .enabled = 1
-        },
-        {
-                .str = "CUSTOMOP",
-                .fn = customop_test,
-                .enabled = 1
-        },
-        {
-                .str = "DES",
-                .fn = des_test,
-                .enabled = 1
-        },
-        {
-                .str = "CCM",
-                .fn = ccm_test,
-                .enabled = 1
-        },
-        {
-                .str = "CMAC",
-                .fn = cmac_test,
-                .enabled = 1
-        },
-        {
-                .str = "ZUC",
-                .fn = zuc_test,
-                .enabled = 1
-        },
-        {
-                .str = "KASUMI",
-                .fn = kasumi_test,
-                .enabled = 1
-        },
-        {
-                .str = "SNOW3G",
-                .fn = snow3g_test,
-                .enabled = 1
-        },
-        {
-                .str = "HMAC_SHA1",
-                .fn = hmac_sha1_test,
-                .enabled = 1
-        },
-        {
-                .str = "HMAC_SHA256",
-                .fn = hmac_sha256_sha512_test,
-                .enabled = 1
-        },
-        {
-                .str = "HMAC_MD5",
-                .fn = hmac_md5_test,
-                .enabled = 1
-        },
-        {
-                .str = "AES",
-                .fn = aes_test,
-                .enabled = 1
-        },
-        {
-                .str = "ECB",
-                .fn = ecb_test,
-                .enabled = 1
-        },
-        {
-                .str = "SHA",
-                .fn = sha_test,
-                .enabled = 1
-        },
-        {
-		.str = "CHAINED",
-                .fn = chained_test,
-                .enabled = 1
-        },
-        {
-                .str = "HEC",
-                .fn = hec_test,
-                .enabled = 1
-        },
-        {
-                .str = "AES_CBCS",
-                .fn = aes_cbcs_test,
-                .enabled = 1
-        },
-        {
-                .str = "CHACHA",
-                .fn = chacha_test,
-                .enabled = 1
-        },
-        {
-                .str = "POLY1305",
-                .fn = poly1305_test,
-                .enabled = 1
-        },
-        {
-                .str = "API",
-                .fn = api_test,
-                .enabled = 1
-        },
-        {
-                .str = "DIRECT_API",
-                .fn = direct_api_test,
-                .enabled = 1
-        },
-        {
-                .str = "CLEAR_MEM",
-                .fn = clear_mem_test,
-                .enabled = 1
-        },
-        {
-                .str = "CRC",
-                .fn = crc_test,
-                .enabled = 1
-        },
-        {
-                .str = "CHACHA20_POLY1305",
-                .fn = chacha20_poly1305_test,
-                .enabled = 1
-        },
-        {
-                .str = "NULL",
-                .fn = null_test,
-                .enabled = 1
-        },
-        {
-                .str = "SNOW_V",
-                .fn = snow_v_test,
-                .enabled = 1
-        },
-        {
-                .str = "DIRECT_API_PARAM",
-                .fn = direct_api_param_test,
-                .enabled = 1
-        },
-        {
-                .str = "QUIC",
-                .fn = quic_ecb_test,
-                .enabled = 1
-        }
+        { .str = "KAT", .fn = known_answer_test, .enabled = 1 },
+        { .str = "DO_TEST", .fn = do_test, .enabled = 1 },
+        { .str = "CBC", .fn = cbc_test, .enabled = 1 },
+        { .str = "CFB", .fn = cfb_test, .enabled = 1 },
+        { .str = "CTR", .fn = ctr_test, .enabled = 1 },
+        { .str = "PON", .fn = pon_test, .enabled = 1 },
+        { .str = "XCBC", .fn = xcbc_test, .enabled = 1 },
+        { .str = "GCM", .fn = gcm_test, .enabled = 1 },
+        { .str = "GMAC", .fn = gmac_test, .enabled = 1 },
+        { .str = "GHASH", .fn = ghash_test, .enabled = 1 },
+        { .str = "CUSTOMOP", .fn = customop_test, .enabled = 1 },
+        { .str = "DES", .fn = des_test, .enabled = 1 },
+        { .str = "CCM", .fn = ccm_test, .enabled = 1 },
+        { .str = "CMAC", .fn = cmac_test, .enabled = 1 },
+        { .str = "ZUC_EEA3", .fn = zuc_eea3_test, .enabled = 1 },
+        { .str = "ZUC_EIA3", .fn = zuc_eia3_test, .enabled = 1 },
+        { .str = "KASUMI", .fn = kasumi_test, .enabled = 1 },
+        { .str = "SNOW3G", .fn = snow3g_test, .enabled = 1 },
+        { .str = "HMAC_SHA1", .fn = hmac_sha1_test, .enabled = 1 },
+        { .str = "HMAC_SHA256", .fn = hmac_sha256_sha512_test, .enabled = 1 },
+        { .str = "HMAC_MD5", .fn = hmac_md5_test, .enabled = 1 },
+        { .str = "AES", .fn = aes_test, .enabled = 1 },
+        { .str = "ECB", .fn = ecb_test, .enabled = 1 },
+        { .str = "SHA", .fn = sha_test, .enabled = 1 },
+        { .str = "CHAINED", .fn = chained_test, .enabled = 1 },
+        { .str = "HEC", .fn = hec_test, .enabled = 1 },
+        { .str = "AES_CBCS", .fn = aes_cbcs_test, .enabled = 1 },
+        { .str = "CHACHA", .fn = chacha_test, .enabled = 1 },
+        { .str = "POLY1305", .fn = poly1305_test, .enabled = 1 },
+        { .str = "API", .fn = api_test, .enabled = 1 },
+        { .str = "DIRECT_API", .fn = direct_api_test, .enabled = 1 },
+        { .str = "CLEAR_MEM", .fn = clear_mem_test, .enabled = 1 },
+        { .str = "CRC", .fn = crc_test, .enabled = 1 },
+        { .str = "CHACHA20_POLY1305", .fn = chacha20_poly1305_test, .enabled = 1 },
+        { .str = "NULL", .fn = null_test, .enabled = 1 },
+        { .str = "SNOW_V", .fn = snow_v_test, .enabled = 1 },
+        { .str = "DIRECT_API_PARAM", .fn = direct_api_param_test, .enabled = 1 },
+        { .str = "QUIC-ECB", .fn = quic_ecb_test, .enabled = 1 },
+        { .str = "QUIC_CHACHA20", .fn = quic_chacha20_test, .enabled = 1 },
+        { .str = "SM4_ECB", .fn = sm4_ecb_test, .enabled = 1 },
+        { .str = "SM4_CBC", .fn = sm4_cbc_test, .enabled = 1 },
+        { .str = "SM3", .fn = sm3_test, .enabled = 1 },
+        { .str = "HMAC_SM3", .fn = hmac_sm3_test, .enabled = 1 }
 };
 
-static char *get_test_types(void)
+static int self_test_corrupt = 0;
+
+static char *
+get_test_types(void)
 {
         const size_t separator_length = 2;
         size_t buffer_sz = 1; /* 1 for NULL termination */
@@ -292,24 +209,27 @@ usage(const char *name)
 {
         char *test_types = get_test_types();
 
-	fprintf(stderr,
+        fprintf(stderr,
                 "Usage: %s [args], where args are zero or more\n"
                 "--help: Prints this page\n"
                 "--test-type <TEST_NAME>: Run selected test type. <TEST_NAME> is one of %s.\n"
                 "--stop-on-fail: Stop test execution if a test fails\n"
                 "--no-aesni-emu: Don't do AESNI emulation\n"
                 "--no-avx512: Don't do AVX512\n"
-		"--no-avx2: Don't do AVX2\n"
-		"--no-avx: Don't do AVX\n"
-		"--no-sse: Don't do SSE\n"
+                "--no-avx2: Don't do AVX2\n"
+                "--no-avx: Don't do AVX\n"
+                "--no-sse: Don't do SSE\n"
                 "--auto-detect: Auto detects current architecture "
                 "to run the tests\n  Note: Auto detection "
                 "option now run by default and will be removed in the future\n"
                 "--gfni-on: Use Galois Field extensions, default: auto-detect\n"
                 "--gfni-off: Don't use Galois Field extensions\n"
-		"--shani-on: Use SHA extensions, default: auto-detect\n"
-		"--shani-off: Don't use SHA extensions\n"
-		"--quiet: Enable quiet mode with reduced text output\n",
+                "--shani-on: Use SHA extensions, default: auto-detect\n"
+                "--shani-off: Don't use SHA extensions\n"
+                "--quiet: Enable quiet mode with reduced text output\n"
+                "--self-test-info: provides information about self-test progress (> v1.4)\n"
+                "--self-test-corrupt: corrupt message during self-test (> v1.4; expect "
+                "initialization fail)\n",
                 name, test_types);
 
         free(test_types);
@@ -322,20 +242,14 @@ print_hw_features(void)
                 uint64_t feat_val;
                 const char *feat_name;
         } feat_tab[] = {
-                { IMB_FEATURE_SHANI, "SHANI" },
-                { IMB_FEATURE_AESNI, "AESNI" },
-                { IMB_FEATURE_PCLMULQDQ, "PCLMULQDQ" },
-                { IMB_FEATURE_CMOV, "CMOV" },
-                { IMB_FEATURE_SSE4_2, "SSE4.2" },
-                { IMB_FEATURE_AVX, "AVX" },
-                { IMB_FEATURE_AVX2, "AVX2" },
-                { IMB_FEATURE_AVX512_SKX, "AVX512(SKX)" },
-                { IMB_FEATURE_VAES, "VAES" },
-                { IMB_FEATURE_VPCLMULQDQ, "VPCLMULQDQ" },
-                { IMB_FEATURE_GFNI, "GFNI" },
-                { IMB_FEATURE_AVX512_IFMA, "AVX512-IFMA" },
-                { IMB_FEATURE_AVX_IFMA, "AVX-IFMA" },
-                { IMB_FEATURE_BMI2, "BMI2" },
+                { IMB_FEATURE_SHANI, "SHANI" },         { IMB_FEATURE_AESNI, "AESNI" },
+                { IMB_FEATURE_PCLMULQDQ, "PCLMULQDQ" }, { IMB_FEATURE_CMOV, "CMOV" },
+                { IMB_FEATURE_SSE4_2, "SSE4.2" },       { IMB_FEATURE_AVX, "AVX" },
+                { IMB_FEATURE_AVX2, "AVX2" },           { IMB_FEATURE_AVX512_SKX, "AVX512(SKX)" },
+                { IMB_FEATURE_VAES, "VAES" },           { IMB_FEATURE_VPCLMULQDQ, "VPCLMULQDQ" },
+                { IMB_FEATURE_GFNI, "GFNI" },           { IMB_FEATURE_AVX512_IFMA, "AVX512-IFMA" },
+                { IMB_FEATURE_AVX_IFMA, "AVX-IFMA" },   { IMB_FEATURE_BMI2, "BMI2" },
+                { IMB_FEATURE_HYBRID, "HYBRID-CORE" }
         };
         IMB_MGR *p_mgr = NULL;
         unsigned i;
@@ -395,12 +309,43 @@ check_err_no_aesni_emu(const uint64_t feature_flags, IMB_MGR *p_mgr)
         return 0;
 }
 
+static int
+self_test_cb(void *arg, const IMB_SELF_TEST_CALLBACK_DATA *data)
+{
+        const char *phase = "";
+        const char *type = "";
+        const char *descr = "";
+
+        (void) arg;
+
+        if (data != NULL) {
+                if (data->phase != NULL)
+                        phase = data->phase;
+                if (data->type != NULL)
+                        type = data->type;
+                if (data->descr != NULL)
+                        descr = data->descr;
+        }
+
+        if (strcmp(phase, IMB_SELF_TEST_PHASE_START) == 0)
+                printf("%s : %s : ", type, descr);
+
+        if ((strcmp(phase, IMB_SELF_TEST_PHASE_CORRUPT) == 0) && (self_test_corrupt == 1))
+                return 0;
+
+        if (strcmp(phase, IMB_SELF_TEST_PHASE_PASS) == 0 ||
+            strcmp(phase, IMB_SELF_TEST_PHASE_FAIL) == 0)
+                printf("%s\n", phase);
+
+        return 1;
+}
+
 int
 main(int argc, char **argv)
 {
         uint8_t arch_support[IMB_ARCH_NUM];
         uint8_t arch_select[IMB_ARCH_NUM];
-        int i, atype, auto_detect = 0;
+        int i, atype, auto_detect = 0, self_test_info = 0;
         uint64_t flags = 0;
         int errors = 0;
         unsigned int stop_on_fail = 0;
@@ -408,34 +353,33 @@ main(int argc, char **argv)
 
         memset(arch_select, 0xff, sizeof(arch_select));
 
-	for (i = 1; i < argc; i++) {
-		if (strcmp(argv[i], "-h") == 0 ||
-                    strcmp(argv[i], "--help") == 0) {
-			usage(argv[0]);
-			return EXIT_SUCCESS;
-		} else if (update_flags_and_archs(argv[i],
-                                                  arch_select,
-                                                  &flags))
-			continue;
-		else if (strcmp(argv[i], "--auto-detect") == 0)
+        for (i = 1; i < argc; i++) {
+                if (strcmp(argv[i], "-h") == 0 || strcmp(argv[i], "--help") == 0) {
+                        usage(argv[0]);
+                        return EXIT_SUCCESS;
+                } else if (update_flags_and_archs(argv[i], arch_select, &flags))
+                        continue;
+                else if (strcmp(argv[i], "--auto-detect") == 0)
                         (void) auto_detect; /* legacy option - to be removed */
-		else if (strcmp(argv[i], "--stop-on-fail") == 0)
+                else if (strcmp(argv[i], "--stop-on-fail") == 0)
                         stop_on_fail = 1;
-		else if (strcmp(argv[i], "--quiet") == 0)
+                else if (strcmp(argv[i], "--quiet") == 0)
                         quiet_mode = 1;
+                else if (strcmp(argv[i], "--self-test-info") == 0)
+                        self_test_info = 1;
+                else if (strcmp(argv[i], "--self-test-corrupt") == 0)
+                        self_test_corrupt = 1;
                 else if (strcmp(argv[i], "--test-type") == 0) {
                         unsigned selected_test;
 
-                        selected_test = check_test_string_arg(argv[i],
-                                                              argv[i+1]);
+                        selected_test = check_test_string_arg(argv[i], argv[i + 1]);
                         if (selected_test == DIM(tests))
                                 return EXIT_FAILURE;
                         else {
                                 /* Disable all tests except the one passed */
                                 unsigned test_idx;
 
-                                for (test_idx = 0; test_idx < DIM(tests);
-                                     test_idx++)
+                                for (test_idx = 0; test_idx < DIM(tests); test_idx++)
                                         if (test_idx != selected_test)
                                                 tests[test_idx].enabled = 0;
                         }
@@ -451,6 +395,16 @@ main(int argc, char **argv)
                 printf("Tool version: %s\n", IMB_VERSION_STR);
         }
 
+        if (imb_get_version() <= IMB_VERSION(1, 4, 0) && self_test_info) {
+                printf("`self-test-info` not supported in this library version!\n");
+                return EXIT_FAILURE;
+        }
+
+        if (imb_get_version() <= IMB_VERSION(1, 4, 0) && self_test_corrupt) {
+                printf("`self-test-corrupt` not supported in this library version!\n");
+                return EXIT_FAILURE;
+        }
+
         /* Print available CPU features */
         print_hw_features();
 
@@ -490,6 +444,9 @@ main(int argc, char **argv)
                         return EXIT_FAILURE;
                 }
 
+                if (self_test_info)
+                        imb_self_test_set_cb(p_mgr, self_test_cb, NULL);
+
                 switch (atype) {
                 case IMB_ARCH_SSE:
                 case IMB_ARCH_NOAESNI:
@@ -506,12 +463,24 @@ main(int argc, char **argv)
                         break;
                 }
 
-                if (p_mgr->features & IMB_FEATURE_SELF_TEST)
+                if (p_mgr->features & IMB_FEATURE_SELF_TEST) {
                         printf("SELF-TEST: %s\n",
-                               (p_mgr->features & IMB_FEATURE_SELF_TEST_PASS) ?
-                               "PASS" : "FAIL");
-                else
+                               (p_mgr->features & IMB_FEATURE_SELF_TEST_PASS) ? "PASS" : "FAIL");
+
+                        if (self_test_corrupt) {
+                                printf("SELF-TEST: CORRUPT option enabled. %s\n",
+                                       ((p_mgr->features & IMB_FEATURE_SELF_TEST_PASS) == 0)
+                                               ? "FAIL expected."
+                                               : "ERROR: PASS NOT EXPECTED!");
+
+                                if ((p_mgr->features & IMB_FEATURE_SELF_TEST_PASS) != 0) {
+                                        free_mb_mgr(p_mgr);
+                                        return EXIT_FAILURE;
+                                }
+                        }
+                } else {
                         printf("SELF-TEST: N/A (requires library >= v1.3)\n");
+                }
 
                 if (imb_get_errno(p_mgr) != 0) {
                         printf("Error initializing MB_MGR structure! %s\n",
